@@ -8,7 +8,6 @@ import os #for access folder
 import numpy as np   #for calculaiton
 import matplotlib as mpl
 import matplotlib.pyplot as plt
-import mplcursors
 
 # from openpyxl import load_workbook
 from datetime import datetime
@@ -445,7 +444,7 @@ class Ui_MainWindow(object):
         self.label_sessiondur.setText(_translate("MainWindow", "Session duration (mins)"))
         self.plot.setText(_translate("MainWindow", "Plot"))
         self.tabs.setTabText(self.tabs.indexOf(self.dataexplorer), _translate("MainWindow", "Data Explorer"))
-        self.info_label.setText(_translate("MainWindow", "Current version v3.0.9 \n"
+        self.info_label.setText(_translate("MainWindow", "Current version v3.10.0 \n"
 "Created by Yifeng Cheng, Ph.D. \n"
 "Contact:\n"
 "(979)571-8531\n"
@@ -681,7 +680,6 @@ class MyApp (QtWidgets.QMainWindow, Ui_MainWindow):
                 text = 'count = %s,lat(s) = %.2f\nmean_IEI(s) = %.2f [max = %.2fs, min = %.2fs]'%(count, lat[idx-1], mean_iei[idx-1], max_iei[idx-1], min_iei[idx-1])
                 ax.text(0, idx/len(counts), text, transform = ax.transAxes, fontsize = 8, verticalalignment = 'top', bbox = props_inplot)
                 
-        mplcursors.cursor(highlight=True).connect("add", lambda sel: sel.annotation.set_text(sel.artist.get_label()))
         # fig1.patch.set_facecolor('none')
         # fig1.patch.set_alpha(0)
         fig.tight_layout()
