@@ -11,10 +11,11 @@ def medpc_read (file, working_var_label='', rat_id=None, save=True, skipold = Tr
     '''
     Inputs:
     1. file (str, path)
-    2. rat_id   (array like)
-    3. save (Bolean value,default is True)
-    4. override (Bolean value, default is True)
-    5. replace  (Bolean value, default is True)
+    2. working_var_label (str, default is '')
+    3. rat_id   (array like)
+    4. save (Bolean value,default is True)
+    5. override (Bolean value, default is True)
+    6. replace  (Bolean value, default is True)
     
     Outputs:
     1. TS_df_tree (a tree, like {'date':{'rat':df}})
@@ -93,8 +94,8 @@ def medpc_read (file, working_var_label='', rat_id=None, save=True, skipold = Tr
             varnameLists =  [line for line in variables if not re.search('\w:\s+', line) and line != '']
             #find common variable names between MSN protocol and datafile
             common_vars = [var.strip(":") for var in varnameLists if var.strip(":") in TS_var_name_map.keys()]
-            #assume array A is alwasy store working variables
-            common_vars += ['A']
+            # #assume array A is alwasy store working variables
+            # common_vars += ['A'] # remove this line cannot assume there is always A array inside the file
             common_vars.sort()  #sort the common variables to make sure they are in order
             data_dict = {}
             
